==> haskell-old-time-1.1.0.3-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-old-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 old-time
version:              1.1.0.3
visibility:           public
id:                   old-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9
key:                  old-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Time library
description:
    This package provides the old time library.

    For new projects, the newer
    <http://hackage.haskell.org/package/time time library>
    is recommended.

category:             System
abi:                  7cad698cf4acfe509cc74d52d25b92c3
exposed:              True
exposed-modules:      System.Time
import-dirs:          /usr/lib/ghc-8.8.3/site-local/old-time-1.1.0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/old-time-1.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/old-time-1.1.0.3
hs-libraries:         HSold-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9
include-dirs:         /usr/lib/ghc-8.8.3/site-local/old-time-1.1.0.3/include
includes:             HsTime.h
depends:
    base-4.13.0.0 old-locale-1.0.0.7-KOGgqu8HfWChZyQBUEp1c

haddock-interfaces:   /usr/share/doc/haskell-old-time/html/old-time.haddock
haddock-html:         /usr/share/doc/haskell-old-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-old-time-1.1.0.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-old-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 old-time
version:              1.1.0.3
visibility:           public
id:                   old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK
key:                  old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Time library
description:
    This package provides the old time library.

    For new projects, the newer
    <http://hackage.haskell.org/package/time time library>
    is recommended.

category:             System
abi:                  45dd92ba8c2090fe355b93978b0e225d
exposed:              True
exposed-modules:      System.Time
import-dirs:          /usr/lib/ghc-8.10.2/site-local/old-time-1.1.0.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/old-time-1.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/old-time-1.1.0.3
hs-libraries:         HSold-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK
include-dirs:         /usr/lib/ghc-8.10.2/site-local/old-time-1.1.0.3/include
includes:             HsTime.h
depends:
    base-4.14.1.0 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P

haddock-interfaces:   /usr/share/doc/haskell-old-time/html/old-time.haddock
haddock-html:         /usr/share/doc/haskell-old-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
